/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*-
 *
 *  Medusa
 *
 *  interface.c -- Signal handler functions and some helpers for msearch-gui.
 *
 *  Copyright (C) 2003 Curtis C. Hovey
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  Authors: Curtis C. Hovey <sinzui@cox.net>
 */
 

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <glib.h>
#include <gtk/gtk.h>
#include <libgnomeui/gnome-icon-theme.h>
#include <glade/glade.h>

#include "interface.h"
#include "msearch-gui.h"

/* helper declarations */
static void	create_emblem_menu		(void);

void		clear_clause				(gpointer	in_clause,
						 	 gpointer       nothing);
						 
void		clear_clause_part			(gpointer	in_clause_part,
							 gpointer	nothing);
							 
void		find_clause				(gpointer	clause,
							 gpointer       query_string);
						 
void		find_clause_parts			(gpointer	in_clause_parts,
							 gpointer	query_string);

/* callback declarations */
gboolean	on_complex_search_dialog_destroy	(GtkObject	*object,
							 gpointer	user_data);

void		on_criteria_checkbutton_toggled		(GtkToggleButton	*togglebutton,
							 gpointer	user_data);

void		set_criteria_sensative			(gpointer	data,
							 gpointer	user_data);

void		set_criteria_insensative		(gpointer	data,
							 gpointer	user_data);
				       
void		on_clear_button_clicked			(GtkButton	*button,
							 gpointer	user_data);
							 
gboolean	on_sidebar_entry_key_press 		(GtkWidget 	*entry,
							 GdkEventKey 	*event, 
							 gpointer 	user_data);

void		on_find_buttton_clicked			(GtkWidget	*button,
							 gpointer	user_data);

gboolean	on_gsearch_app_destroy_event		(GtkEntry	*entry,
							 GdkEvent	*event,
							 gpointer	user_data);

void		on_menuitem_quit_activate		(GtkMenuItem	*menuitem,
							 gpointer	user_data);

void		on_menuitem_copy_activate		(GtkMenuItem	*menuitem,
							 gpointer	user_data);

void		on_complex_button_clicked		(GtkButton	*button,
							 gpointer	user_data);

void		on_simple_button_clicked		(GtkButton	*button,
							 gpointer	user_data);

void		on_msearch_gui_button_clicked		(GtkButton	*button,
							 gpointer	user_data);

gboolean	on_msearch_gui_app_destroy		(GtkObject	*object,
							 gpointer	user_data);

gboolean	on_simple_search_dialog_destroy		(GtkObject	*object,
							 gpointer	user_data);

void		on_simple_search_file_name_buttton_clicked	(GtkButton	*button,
								 gpointer	user_data);

void		on_close_buttton_clicked		(GtkButton	*button,
							 gpointer	user_data);

void		on_sidebar_clear_button_clicked		(GtkButton      *button,
							 gpointer	user_data);
				    
void		on_sidebar_find_button_clicked		(GtkWidget      *button,
							 gpointer	user_data);

void		on_msearch_quit_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_new_activate			(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_preferences_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_copy_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_save_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_properties_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_cut_activate			(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_open_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_save_as_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_paste_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_clear_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);
 
void		on_msearch_about_activate		(GtkImageMenuItem *imagemenuitem,
							 gpointer	user_data);


#define ICON_SIZE 24.0

GladeXML *xml;
GHashTable *more_options;
GHashTable *fewer_options;

gboolean row_selected_by_button_press_event;

/*
 * msearch_interface_init:
 * 
 * @in_xml: the msearch-gui GladeXML.
 * 
 * Executes gets the msearch_gui_app, set's it up, and creates the alternate
 * label text for the toggle buttons.
 * 
 * returns: msearch_gui_app (top-level window) GtkWidget.
 */
GtkWidget *
msearch_interface_init (GladeXML *in_xml)
{
	GtkWidget *msearch_gui_app;
	gboolean state_on;
	GtkWidget *sidebar_file_name_vbox;
	GError *err;
	
	g_return_val_if_fail (NULL != in_xml, NULL);
	xml = in_xml;

	msearch_gui_app = glade_xml_get_widget (xml, "msearch_gui_app");
	if (NULL == msearch_gui_app) {
		g_error(_("Cannot get the application window."));
		return NULL;
	}
	
	// force broken signal to work
	g_signal_connect (G_OBJECT (msearch_gui_app), 
			  "delete_event",
			  G_CALLBACK (on_msearch_gui_app_destroy),
			  msearch_gui_app);

	err = NULL;
	gtk_window_set_icon_from_file (GTK_WINDOW (msearch_gui_app), MSEARCH_DEFAULT_ICON, &err);
	if (NULL != err) {
		g_warning (_("Cannot set the application's default icon:"));
		g_warning (err->message);
		g_error_free (err);
	}
	
	
	state_on = TRUE;
	sidebar_file_name_vbox = glade_xml_get_widget (xml, "sidebar_content_vbox");
	g_object_set_data (G_OBJECT (sidebar_file_name_vbox), "is_active", 
			   (gpointer) state_on);
	
	more_options = g_hash_table_new (g_str_hash, g_str_equal);
	g_hash_table_insert (more_options, 
			     "sidebar_content_checkbutton", 
			      _("More content options"));
	g_hash_table_insert (more_options, 
			     "sidebar_file_name_checkbutton", 
			      _("More file name options"));
	g_hash_table_insert (more_options, 
			     "sidebar_file_type_checkbutton", 
			      _("More file type options"));
	g_hash_table_insert (more_options, 
			     "sidebar_directory_name_checkbutton", 
			      _("More file location options"));
	g_hash_table_insert (more_options, 
			     "sidebar_keywords_checkbutton", 
			      _("More emblem options"));
	g_hash_table_insert (more_options, 
			     "sidebar_modified_checkbutton", 
			      _("More last modified options"));
	g_hash_table_insert (more_options, 
			     "sidebar_size_checkbutton", 
			      _("More file size options"));
	g_hash_table_insert (more_options, 
			     "sidebar_owner_checkbutton", 
			      _("More owner options"));
	g_hash_table_insert (more_options, 
			     "sidebar_group_checkbutton", 
			      _("More group options"));
	
	fewer_options = g_hash_table_new (g_str_hash, g_str_equal);
	g_hash_table_insert (fewer_options, 
			     "sidebar_content_checkbutton", 
			      _("Fewer content options"));
	g_hash_table_insert (fewer_options, 
			     "sidebar_file_name_checkbutton", 
			      _("Fewer file name options"));
	g_hash_table_insert (fewer_options, 
			     "sidebar_file_type_checkbutton", 
			      _("Fewer file type options"));
	g_hash_table_insert (fewer_options, 
			     "sidebar_directory_name_checkbutton", 
			      _("Fewer file location options"));
	g_hash_table_insert (fewer_options, 
			     "sidebar_keywords_checkbutton", 
			      _("Fewer emblem options"));
	g_hash_table_insert (fewer_options, 
			     "sidebar_modified_checkbutton", 
			      _("Fewer last modified options"));
	g_hash_table_insert (fewer_options, 
			     "sidebar_size_checkbutton", 
			      _("Fewer file size options"));
	g_hash_table_insert (fewer_options, 
			     "sidebar_owner_checkbutton", 
			      _("Fewer owner options"));
	g_hash_table_insert (fewer_options, 
			     "sidebar_group_checkbutton", 
			      _("Fewer group options"));
			      
	create_emblem_menu ();
	
	return msearch_gui_app;
}


/*
 * create_emblem_menu:
 * 
 * Creates the emblem value optionmenu with pixbufs and text.
 * 
 * returns: void.
 */
static void				
create_emblem_menu (void)
{
	GtkWidget *value_menu;
	GnomeIconTheme *icon_theme;
	GList *emblem_list;
	GtkWidget *option_menu;
	
	value_menu = gtk_menu_new ();
	icon_theme = gnome_icon_theme_new ();
	gnome_icon_theme_set_allow_svg (icon_theme, TRUE);
	emblem_list = gnome_icon_theme_list_icons (icon_theme, "Emblems");
	
	while (NULL != emblem_list) {
		char *emblem;
		char *keyword;
		GdkPixbuf *pixbuf;
		GtkWidget *image;
		GtkWidget *menu_item;
		char *emblem_path; 
		const GnomeIconData *icon_data;
		int base_size;
		
		emblem = (char *) emblem_list->data;
		if (g_str_has_prefix (emblem, "emblem-")) {
			keyword = g_strdup (&emblem[7]);
		} 
		else {
			keyword = g_strdup (emblem);
		}

		if (strcmp (keyword, "erase") == 0) {
			g_free (emblem);
			g_free (keyword);
			
			emblem_list = emblem_list->next;
			continue;
		}
		
		emblem_path = gnome_icon_theme_lookup_icon (icon_theme, 
							    emblem, ICON_SIZE, 
							    &icon_data, &base_size);
		pixbuf = gdk_pixbuf_new_from_file (emblem_path, NULL);
		image = gtk_image_new_from_pixbuf (pixbuf);
		g_free (emblem_path);
		
		menu_item = gtk_image_menu_item_new_with_label (keyword);
		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_item), 
					       image);
		gtk_widget_set_name (GTK_WIDGET (menu_item), g_strdup (keyword));
		gtk_widget_show_all (menu_item);
		gtk_menu_shell_append (GTK_MENU_SHELL (value_menu), menu_item);
		
		g_object_unref (pixbuf);
		g_free (keyword);
		g_free (emblem);
		
		emblem_list = emblem_list->next;
	}
		
	gtk_widget_show_all (GTK_WIDGET (value_menu));

	option_menu = glade_xml_get_widget (xml, "sidebar_emblem_value_optionmenu");
	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), value_menu);
}


/*
 * on_criteria_checkbutton_toggled:
 * 
 * @toggle_button: The GTKToggleButton that was clicked.
 * @user_data: a gpointer that is not used.
 * 
 * The callback that controls the behavior of the search criteria toggle buttons.
 * 
 * returns: void.
 */
void
on_criteria_checkbutton_toggled	(GtkToggleButton *toggle_button, gpointer user_data)
{
	gboolean is_active;
	GtkWidget *parent;
	const char *parent_name;
	GList *children;
	
	is_active = gtk_toggle_button_get_active (toggle_button);
	parent = gtk_widget_get_parent (GTK_WIDGET (toggle_button));
	parent_name = gtk_widget_get_name (parent);
	g_object_set_data (G_OBJECT (parent), "is_active", (gpointer) is_active);
	
	children = gtk_container_get_children (GTK_CONTAINER (parent));
	
	if (is_active) {
		g_list_foreach (children, set_criteria_sensative, NULL);
	} 
	else {
		g_list_foreach (children, set_criteria_insensative, NULL);
	}
}


/*
 * set_criteria_sensative:
 * 
 * @data: gpointer representing a GtkWidget.
 * @user_data: a gpointer that is not used.
 * 
 * This is a g_list_foreach function that changes the state of the GtkWidget
 * passed to it.  It shows all the widgets, and updated the label of toggle
 * buttons to show 'fewer options'.
 * 
 * returns: void.
 */
void
set_criteria_sensative (gpointer data, gpointer user_data)
{
	GtkWidget *widget;
	gchar *label;
	gboolean state;
	
	g_return_if_fail (data != NULL);
	
	state = TRUE;
	
	widget = (GtkWidget *) data;
	
	if (!GTK_IS_TOGGLE_BUTTON (widget)) {
		if (GNOME_IS_DATE_EDIT (widget)) {
			gtk_widget_show (widget);
		}
		else {
			gtk_widget_show_all (widget);
		}
	}
	else {
		label = (gchar *) g_hash_table_lookup (fewer_options, 
					     gtk_widget_get_name (widget));
		gtk_button_set_label (GTK_BUTTON (widget), g_strdup (label));
	}
}


/*
 * set_criteria_insensative:
 * 
 * @data: gpointer representing a GtkWidget.
 * @user_data: a gpointer that is not used.
 * 
 * This is a g_list_foreach function that changes the state of the GtkWidget
 * passed to it.  It hides all the widgets, and updated the label of toggle
 * buttons to show 'more options'.
 * 
 * returns: void.
 */
void
set_criteria_insensative (gpointer data, gpointer user_data)
{
	GtkWidget *widget;
	gchar *label;
	gboolean state;
	
	g_return_if_fail (data != NULL);
	
	state = FALSE;

	widget = (GtkWidget *) data;
	if (!GTK_IS_TOGGLE_BUTTON (widget)) {
		if (GNOME_IS_DATE_EDIT (widget)) {
			gtk_widget_hide (widget);
		}
		else {
			gtk_widget_hide_all (widget);
		}
	}
	else {
		label = (gchar *) g_hash_table_lookup (more_options, 
					     gtk_widget_get_name (widget));
		gtk_button_set_label (GTK_BUTTON (widget), g_strdup (label));
	}	
}


/*
 * on_sidebar_clear_button_clicked:
 * 
 * @button: The GtkButton that was clicked.
 * @user_data: a gpointer that is not used.
 * 
 * The callback resets or clears the search clauses.
 * 
 * returns: void.
 */
void
on_sidebar_clear_button_clicked	(GtkButton *button, gpointer user_data)
{
	GtkWidget *sidebar_clauses_vbox;
	GList *clauses;
	
	sidebar_clauses_vbox = glade_xml_get_widget (xml, "sidebar_clauses_vbox");
	clauses = gtk_container_get_children (GTK_CONTAINER (sidebar_clauses_vbox));
	g_list_foreach (clauses, clear_clause, NULL);
}


/*
 * clear_clause:
 * 
 * @data: gpointer representing a GtkWidget that is a Medusa clause.
 * @user_data: a gpointer that is not used.
 * 
 * This is a g_list_foreach function that resets or clears all the children of 
 * GtkWidget passed to it.
 * 
 * returns: void.
 */
void
clear_clause (gpointer in_clause, gpointer nothing)
{
	GtkWidget *clause_vbox;
	GList *clause_parts;
	
	g_return_if_fail (in_clause);
	
	clause_vbox = (GtkWidget *) in_clause;
	
	clause_parts = gtk_container_get_children (GTK_CONTAINER (clause_vbox));
	
	g_list_foreach (clause_parts, clear_clause_part, NULL);
}


/*
 * clear_clause_part:
 * 
 * @data: gpointer representing a GtkWidget that is a part of a Medusa clause.
 * @user_data: a gpointer that is not used.
 * 
 * This is a g_list_foreach function that changes the state of the GtkWidget
 * passed to it.  It resets or clears all the widgets, and updated the label of toggle
 * buttons to show 'more options'.
 * 
 * returns: void.
 */
void
clear_clause_part (gpointer in_clause_part, gpointer nothing)
{
	GtkWidget *clause_part;
	
	g_return_if_fail (in_clause_part);
	
	clause_part = (GtkWidget *) in_clause_part;
	
	if (GTK_IS_TOGGLE_BUTTON (clause_part)) {
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (clause_part), 
			FALSE);
		set_criteria_insensative ( (gpointer) clause_part, NULL);
	}
	else if (GTK_IS_OPTION_MENU (clause_part)) {
		GtkWidget *menu;
		
		menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (clause_part));
		gtk_menu_set_active (GTK_MENU (menu), 0);
		set_criteria_insensative ( (gpointer) clause_part, NULL);
	}
	else if (GTK_IS_ENTRY (clause_part)) {
		gtk_entry_set_text (GTK_ENTRY (clause_part), "");
		set_criteria_insensative ( (gpointer) clause_part, NULL);
	}
	else if (GNOME_IS_DATE_EDIT (clause_part)) {
		GTimeVal time_val;
		time_t time;
		
		g_get_current_time (&time_val);
		time = (time_t) time_val.tv_sec;
		
		gnome_date_edit_set_time (GNOME_DATE_EDIT (clause_part), time);
		set_criteria_insensative ( (gpointer) clause_part, NULL);
	}
}


/*
 * on_sidebar_entry_key_press:
 * 
 * @entry: the GtkEntry that was modified.
 * @GdkEventKey: the event state.
 * @user_data: a gpointer that is not used.
 * 
 * The callback calls the on_sidebar_find_button_clicked handler()
 * when %GDK_Return is entered into an GtkEntry to execute the search.
 * 
 * returns: signal state, gboolean TRUE or FALSE.
 */
gboolean
on_sidebar_entry_key_press (GtkWidget *entry, GdkEventKey *event, gpointer user_data)
{
	g_return_val_if_fail (entry, FALSE);
	g_return_val_if_fail (GTK_IS_ENTRY (entry), FALSE);
	
	if (event->keyval == GDK_Return) {
		on_sidebar_find_button_clicked (entry, user_data);
		return TRUE;
	}
	
	return FALSE;
}


/*
 * on_sidebar_find_button_clicked:
 * 
 * @button: The GtkButton that was clicked.
 * @user_data: a gpointer that is not used.
 * 
 * The callback constructs a search url and passes it to the
 * exec_search() function.
 * 
 * returns: void.
 */
void
on_sidebar_find_button_clicked (GtkWidget *button, gpointer user_data)
{
	GtkWidget *sidebar_clauses_vbox;
	GList *clauses;
	GString *query_string;

	query_string = g_string_new ("");
	
	sidebar_clauses_vbox = glade_xml_get_widget (xml, "sidebar_clauses_vbox");
	clauses = gtk_container_get_children (GTK_CONTAINER (sidebar_clauses_vbox));
	g_list_foreach (clauses, find_clause, (gpointer) query_string);

	g_string_erase (query_string, 0, 3);
	g_string_prepend (query_string, "search:[file:///]");
	
	exec_search (query_string->str);
	
	g_string_free (query_string, TRUE);
}


/*
 * find_clause:
 * 
 * @clause: gpointer representing a GtkWidget that is a Medusa clause.
 * @query_string: a gpointer to the query URL.
 * 
 * This is a g_list_foreach function that locates the active clauses and
 * pass them to find_clause_parts to construct the query_string.
 * 
 * returns: void.
 */
void
find_clause (gpointer clause, gpointer query_string)
{
	GtkWidget *clause_vbox;
	GList *clause_parts;
	gboolean is_active;
	
	g_return_if_fail (clause);
	
	clause_vbox = (GtkWidget *) clause;

	is_active = (gboolean) g_object_get_data (G_OBJECT (clause_vbox), "is_active");
	if (is_active) {
		clause_parts = gtk_container_get_children (GTK_CONTAINER (clause_vbox));
		find_clause_parts (clause_parts, query_string);
	}
}


/*
 * find_clause_parts:
 * 
 * @clause_parts: gpointer representing a GList of GtkWidgets comprising a Medusa clause.
 * @query_string: a gpointer to the query URL.
 * 
 * This function constucts a subject, predicate, and optional object clause and 
 * appends it to the query_string.
 * 
 * returns: void.
 */
void
find_clause_parts (gpointer in_clause_parts, gpointer query_string)
{
	GList *clause_parts;
	char *subject;
	char *predicate;
	char *object;
	
	g_return_if_fail (in_clause_parts);
	
	clause_parts = (GList *) in_clause_parts;
	
	subject = NULL;
	predicate = NULL;
	object = NULL;
	
	while (NULL != clause_parts) {
		GtkWidget *clause_part;
		
		clause_part = (GtkWidget *) clause_parts->data;
		
		if (NULL == clause_part) {
			break;
		}
		
		if (GTK_IS_TOGGLE_BUTTON (clause_part)) {
			const gchar *clause_name;
			gchar *sub_clause_name;
			gsize subject_len;
			
			clause_name = gtk_widget_get_name (GTK_WIDGET (clause_part));
			
			/* must parse name for subject */
			sub_clause_name = strstr (clause_name, "_") + 1;
			subject_len = g_strrstr (sub_clause_name, "_") - sub_clause_name;
			sub_clause_name = g_strndup (sub_clause_name, subject_len);
			subject =  g_strdup (sub_clause_name);
		}
		else if (GTK_IS_OPTION_MENU (clause_part)) {
			GtkWidget *menu;
			GtkWidget *menu_item;
			const gchar *menuitem_name;
			const gchar *optionmenu_name;
			gchar *offsetpos;
			gchar *startpos;
			
			optionmenu_name = gtk_widget_get_name (GTK_WIDGET (clause_part));
			
			menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (clause_part));
			menu_item = gtk_menu_get_active (GTK_MENU (menu));
			menuitem_name = gtk_widget_get_name (GTK_WIDGET (menu_item));
			
			if (!(g_ascii_strcasecmp ((gchar *) "sidebar_emblem_value_optionmenu", 
			(const gchar *) optionmenu_name))) {
				object = g_strdup (menuitem_name);
			}
			else if (!(g_ascii_strcasecmp ((gchar *) "sidebar_type_value_optionmenu", 
			(const gchar *) optionmenu_name))) {
				offsetpos = strstr (menuitem_name, "_") + 1;
				startpos = strstr (offsetpos, "_") + 1;
				object = g_strdup (startpos);
			}
			else {
				offsetpos = strstr (menuitem_name, "_") + 1;
				startpos = strstr (offsetpos, "_") + 1;
				predicate = g_strdup (startpos);
			}
		}
		else if (GTK_IS_ENTRY (clause_part)) {
			gchar *string;
			
			string = g_strdup (gtk_entry_get_text (GTK_ENTRY (clause_part)));
			object = g_strstrip (string);
		}
		else if (GNOME_IS_DATE_EDIT (clause_part)) {
			GDate *date;
			time_t time;
			GDateMonth month;
			GDateDay day;
			GDateYear year;
			
			date = g_date_new ();
			time = gnome_date_edit_get_time (GNOME_DATE_EDIT (clause_part));
			g_date_set_time (date, (GTime) time);
			
			month = g_date_get_month (date);
			day = g_date_get_day (date);
			year = g_date_get_year (date);
			object = g_strdup_printf ("%02i/%02i/%4i", month, day, year);
			
			g_date_free (date);
		}
		clause_parts = clause_parts->next;
	}
	
	g_string_append ((GString *) query_string, 
			 g_strdup_printf (" & %s %s %s", subject, predicate, object));
	
	
	g_free (subject);
	g_free (predicate);
	g_free (object);
}


/*
 * on_msearch_gui_app_destroy:
 * 
 * @object: The GtkObject activated from the window.
 * @user_data: a gpointer that is not used.
 * 
 * The callback quits msearch-gui.
 * 
 * returns: void.
 */
gboolean
on_msearch_gui_app_destroy (GtkObject *object, gpointer user_data)
{	
	gtk_main_quit ();
	
	return TRUE;
}


/*
 * on_msearch_quit_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * The callback quits msearch-gui.
 * 
 * returns: void.
 */
void
on_msearch_quit_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	gtk_main_quit ();	
}


/*
 * on_msearch_new_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will clear the clauses and start a new desktop item.
 * 
 * returns: void.
 */ 
void
on_msearch_new_activate	(GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}


/*
 * on_msearch_preferences_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will open the Medusa and msearch preferences.
 * 
 * returns: void.
 */
void
on_msearch_preferences_activate	(GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}


/*
 * on_msearch_preferences_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will copy the select results or entry text.
 * 
 * returns: void.
 */ 
void
on_msearch_copy_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}
 

/*
 * on_msearch_save_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will save the search as a desktop item that can be opened
 * from the desktop.
 * 
 * returns: void.
 */
void
on_msearch_save_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}


/*
 * on_msearch_properties_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will show the properties of the selected file in the results.
 * 
 * returns: void.
 */
void
on_msearch_properties_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}


/*
 * on_msearch_cut_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will cut text from a entry.
 * 
 * returns: void.
 */
void
on_msearch_cut_activate	(GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}


/*
 * on_msearch_open_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will open the selected file from results.
 * 
 * returns: void.
 */
void
on_msearch_open_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}


/*
 * on_msearch_save_as_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will save an opened desktop item as a new item.
 * 
 * returns: void.
 */
void
on_msearch_save_as_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}
 

/*
 * on_msearch_paste_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will paste text into an entry.
 * 
 * returns: void.
 */
void
on_msearch_paste_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}

/*
 * on_msearch_clear_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Calls on_sidebar_clear_button_clicked () to clear the clauses.
 * 
 * returns: void.
 */
void
on_msearch_clear_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	on_sidebar_clear_button_clicked ( (gpointer) imagemenuitem, user_data);
}


/*
 * on_msearch_about_activate:
 * 
 * @imagemenuitem: The GtkImageMenuItem activated from the menu.
 * @user_data: a gpointer that is not used.
 * 
 * Does nothing.  Will show the about dialog.
 * 
 * returns: void.
 */
void
on_msearch_about_activate (GtkImageMenuItem *imagemenuitem, gpointer user_data)
{
	
}
